@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTHELP_PYTHON_H
@@ -52,40 +16,23 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtHelp/qhelpfiltersettingswidget.h>
-#include <QtHelp/qhelpfilterdata.h>
-#include <QtHelp/qhelpsearchquerywidget.h>
-#include <QtHelp/qhelpengine.h>
-#include <QtHelp/qhelpsearchresultwidget.h>
-#include <QtHelp/qhelpenginecore.h>
 #include <QtHelp/qhelpsearchengine.h>
-#include <QtHelp/qhelpcontentwidget.h>
-#include <QtHelp/qhelpfilterengine.h>
-#include <QtHelp/qcompressedhelpinfo.h>
-#include <QtHelp/qhelplink.h>
-#include <QtHelp/qhelpindexwidget.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+class QCompressedHelpInfo;
+class QHelpContentItem;
+class QHelpContentModel;
+class QHelpContentWidget;
+class QHelpEngine;
+class QHelpEngineCore;
+class QHelpFilterData;
+class QHelpFilterEngine;
+class QHelpFilterSettingsWidget;
+class QHelpIndexModel;
+class QHelpIndexWidget;
+struct QHelpLink;
+class QHelpSearchEngine;
+class QHelpSearchQueryWidget;
+class QHelpSearchResult;
+class QHelpSearchResultWidget;
 // Type indices
 enum : int {
     SBK_QCOMPRESSEDHELPINFO_IDX                              = 0,
@@ -119,38 +66,37 @@ extern SbkConverter **SbkPySide6_QtHelpTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTHELP_QLIST_INT_IDX                                 = 0, // QList<int >
-    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 1, // QList<QVersionNumber >
-    SBK_QTHELP_QLIST_QMODELINDEX_IDX                         = 2, // QList<QModelIndex >
-    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 3, // QList<QHelpLink >
-    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 4, // QMultiMap<QString,QUrl >
-    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 5, // QList<QAction* >
-    SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 6, // QList<QHelpSearchQuery >
-    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 7, // QList<QObject* >
-    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 8, // QList<QByteArray >
-    SBK_QTHELP_STD_PAIR_QSTRING_QSTRING_IDX                  = 9, // std::pair<QString,QString >
-    SBK_QTHELP_QLIST_STD_PAIR_QSTRING_QSTRING_IDX            = 10, // QList<std::pair< QString,QString > >
-    SBK_QTHELP_QLIST_QHELPSEARCHRESULT_IDX                   = 11, // QList<QHelpSearchResult >
-    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 12, // QMap<QString,QString >
-    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 13, // QMap<QString,QVersionNumber >
-    SBK_QTHELP_QLIST_QURL_IDX                                = 14, // QList<QUrl >
-    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 15, // QList<QStringList >
-    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 16, // QMap<int,QVariant >
-    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 17, // QList<QPersistentModelIndex >
-    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 18, // QHash<int,QByteArray >
-    SBK_QTHELP_QLIST_QVARIANT_IDX                            = 19, // QList<QVariant >
-    SBK_QTHELP_QLIST_QSTRING_IDX                             = 20, // QList<QString >
-    SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                     = 21, // QMap<QString,QVariant >
-    SBK_QtHelp_CONVERTERS_IDX_COUNT                          = 22
+    SBK_QTHELP_QLIST_INT_IDX                                 = 0, // QList<int>
+    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 1, // QList<QVersionNumber>
+    SBK_QTHELP_QLIST_QMODELINDEX_IDX                         = 2, // QList<QModelIndex>
+    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 3, // QList<QHelpLink>
+    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 4, // QMultiMap<QString,QUrl>
+    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 5, // QList<QAction*>
+    SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 6, // QList<QHelpSearchQuery>
+    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 7, // QList<QObject*>
+    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 8, // QList<QByteArray>
+    SBK_QTHELP_STD_PAIR_QSTRING_QSTRING_IDX                  = 9, // std::pair<QString,QString>
+    SBK_QTHELP_QLIST_STD_PAIR_QSTRING_QSTRING_IDX            = 10, // QList<std::pair< QString,QString>>
+    SBK_QTHELP_QLIST_QHELPSEARCHRESULT_IDX                   = 11, // QList<QHelpSearchResult>
+    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 12, // QMap<QString,QString>
+    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 13, // QMap<QString,QVersionNumber>
+    SBK_QTHELP_QLIST_QURL_IDX                                = 14, // QList<QUrl>
+    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 15, // QList<QStringList>
+    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 16, // QMap<int,QVariant>
+    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 17, // QHash<int,QByteArray>
+    SBK_QTHELP_QLIST_QVARIANT_IDX                            = 18, // QList<QVariant>
+    SBK_QTHELP_QLIST_QSTRING_IDX                             = 19, // QList<QString>
+    SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                     = 20, // QMap<QString,QVariant>
+    SBK_QtHelp_CONVERTERS_IDX_COUNT                          = 21
 };
 // Macros for type check
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QCompressedHelpInfo >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QCOMPRESSEDHELPINFO_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpContentItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpContentModel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
@@ -169,9 +115,9 @@ template<> inline PyTypeObject *SbkType< ::QHelpSearchQuery >() { return reinter
 template<> inline PyTypeObject *SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QHELPSEARCHRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
-QT_WARNING_POP
 
 } // namespace Shiboken
 
+QT_WARNING_POP
 #endif // SBK_QTHELP_PYTHON_H
 
