@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTSENSORS_PYTHON_H
@@ -50,48 +14,63 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
-#include <QtSensors/qmagnetometer.h>
-#include <QtSensors/qpressuresensor.h>
-#include <QtSensors/qirproximitysensor.h>
-#include <QtSensors/qtapsensor.h>
-#include <QtSensors/qhumiditysensor.h>
-#include <QtSensors/qlightsensor.h>
-#include <QtSensors/qambienttemperaturesensor.h>
-#include <QtSensors/qgyroscope.h>
-#include <QtSensors/qlidsensor.h>
-#include <QtSensors/qsensormanager.h>
-#include <QtSensors/qtiltsensor.h>
 #include <QtSensors/qaccelerometer.h>
-#include <QtSensors/qcompass.h>
-#include <QtSensors/qsensor.h>
-#include <QtSensors/qsensorplugin.h>
-#include <QtSensors/qrotationsensor.h>
 #include <QtSensors/qambientlightsensor.h>
-#include <QtSensors/qproximitysensor.h>
 #include <QtSensors/qorientationsensor.h>
-#include <QtSensors/qsensorbackend.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+#include <QtSensors/qsensor.h>
+#include <QtSensors/qtapsensor.h>
+class QAccelerometerFilter;
+class QAccelerometerReading;
+class QAmbientLightFilter;
+class QAmbientLightSensor;
+class QAmbientTemperatureFilter;
+class QAmbientTemperatureReading;
+class QAmbientTemperatureSensor;
+class QCompass;
+class QCompassFilter;
+class QCompassReading;
+class QGyroscope;
+class QGyroscopeFilter;
+class QGyroscopeReading;
+class QHumidityFilter;
+class QHumidityReading;
+class QHumiditySensor;
+class QIRProximityFilter;
+class QIRProximityReading;
+class QIRProximitySensor;
+class QLidFilter;
+class QLidReading;
+class QLidSensor;
+class QLightFilter;
+class QLightReading;
+class QLightSensor;
+class QMagnetometer;
+class QMagnetometerFilter;
+class QMagnetometerReading;
+class QOrientationFilter;
+class QOrientationSensor;
+class QPressureFilter;
+class QPressureReading;
+class QPressureSensor;
+class QProximityFilter;
+class QProximityReading;
+class QProximitySensor;
+class QRotationFilter;
+class QRotationReading;
+class QRotationSensor;
+class QSensorBackend;
+class QSensorBackendFactory;
+class QSensorChangesInterface;
+class QSensorFilter;
+class QSensorManager;
+class QSensorPluginInterface;
+class QSensorReading;
+class QTapFilter;
+class QTapSensor;
+class QTiltFilter;
+class QTiltReading;
+class QTiltSensor;
+struct qoutputrange;
 // Type indices
 enum : int {
     SBK_QACCELEROMETER_ACCELERATIONMODE_IDX                  = 1,
@@ -170,26 +149,26 @@ extern SbkConverter **SbkPySide6_QtSensorsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSENSORS_QLIST_INT_IDX                              = 0, // QList<int >
-    SBK_QTSENSORS_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
-    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
-    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 3, // std::pair<int,int >
-    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 4, // QList<std::pair< int,int > >
-    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 5, // QList<QSensorFilter* >
-    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 6, // QList<qoutputrange >
-    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 7, // QList<QVariant >
-    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 8, // QList<QString >
-    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 9, // QMap<QString,QVariant >
+    SBK_QTSENSORS_QLIST_INT_IDX                              = 0, // QList<int>
+    SBK_QTSENSORS_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject*>
+    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray>
+    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 3, // std::pair<int,int>
+    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 4, // QList<std::pair< int,int>>
+    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 5, // QList<QSensorFilter*>
+    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 6, // QList<qoutputrange>
+    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 7, // QList<QVariant>
+    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 8, // QList<QString>
+    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 9, // QMap<QString,QVariant>
     SBK_QtSensors_CONVERTERS_IDX_COUNT                       = 10
 };
 // Macros for type check
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAccelerometer::AccelerationMode >() { return SbkPySide6_QtSensorsTypes[SBK_QACCELEROMETER_ACCELERATIONMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAccelerometer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSensorsTypes[SBK_QACCELEROMETER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAccelerometerFilter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSensorsTypes[SBK_QACCELEROMETERFILTER_IDX]); }
@@ -253,9 +232,9 @@ template<> inline PyTypeObject *SbkType< ::QTiltFilter >() { return reinterpret_
 template<> inline PyTypeObject *SbkType< ::QTiltReading >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSensorsTypes[SBK_QTILTREADING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTiltSensor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSensorsTypes[SBK_QTILTSENSOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::qoutputrange >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSensorsTypes[SBK_QOUTPUTRANGE_IDX]); }
-QT_WARNING_POP
 
 } // namespace Shiboken
 
+QT_WARNING_POP
 #endif // SBK_QTSENSORS_PYTHON_H
 
